@@ -210,17 +210,7 @@ void CPPHeaderCodeDocument::loadChildTextBlocksFromNode (QDomElement & root)
 
     if(!loadCheckForChildrenOK)
     {
-        CodeDocument * test = dynamic_cast<CodeDocument*>(this);
-        if(test)
-        {
-            uWarning()<<" loadChildBlocks : unable to initialize any child blocks in doc: "<<test->getFileName()<<" "<<this;
-        } else {
-            HierarchicalCodeBlock * hb = dynamic_cast<HierarchicalCodeBlock*>(this);
-            if(hb)
-                uWarning()<<" loadChildBlocks : unable to initialize any child blocks in Hblock: "<<hb->getTag()<<" "<<this;
-            else
-                uDebug()<<" loadChildBlocks : unable to initialize any child blocks in UNKNOWN OBJ:"<<this;
-        }
+        uWarning() << "loadChildBlocks : unable to initialize any child blocks in doc: " << getFileName() << " " << this;
     }
 
 }
@@ -828,4 +818,3 @@ void CPPHeaderCodeDocument::updateContent()
     addOrUpdateTaggedCodeBlockWithComments(QLatin1String("hashDefBlockEnd"), defTextEnd, QString(), 0, false);
 }
 
-#include "cppheadercodedocument.moc"
